<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle" width="50%">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="80px"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="编码" prop="code">
            <el-input v-model="formData.code" placeholder="请输入编码" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="抓图方式">
            <el-select v-model="formData.captureType" placeholder="请选择">
              <el-option
                v-for="dict in getStrDictOptions(DICT_TYPE.CAPTURE_TYPE)"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="通道" prop="channel">
            <el-input v-model="formData.channel" placeholder="请输入通道" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="监控区域" prop="location">
            <el-input v-model="formData.location" placeholder="请输入监控区域" />
          </el-form-item>
        </el-col>
      </el-row>

      <el-row>
        <el-col :span="24">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="formData.remark" clearable type="textarea" />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
import * as CameraApi from '@/api/data/dev/camera'
import {DICT_TYPE, getIntDictOptions, getStrDictOptions} from "@/utils/dict";

defineOptions({ name: 'CameraForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗
const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const nvrId = ref('') // 录像机id
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  nvrId: '',
  code: undefined,
  captureType: '',
  channel: undefined,
  location: undefined,
  remark: undefined
})
const formRules = reactive({
  code: [{ required: true, message: '编码不能为空', trigger: 'blur' }],
  captureType: [{ required: true, message: '抓图方式不能为空', trigger: 'blur' }],
  channel: [{ required: true, message: '通道不能为空', trigger: 'blur' }],
  location: [{ required: true, message: '监控区域不能为空', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number, nvr_id?: string) => {
  dialogVisible.value = true
  if (nvr_id != null) {
    nvrId.value = nvr_id
  }
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await CameraApi.getCamera(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  if (!formRef) return
  const valid = await formRef.value.validate()
  if (!valid) return
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as CameraApi.CameraVO
    if (formType.value === 'create') {
      data.nvrId = nvrId.value
      await CameraApi.createCamera(data)
      message.success(t('common.createSuccess'))
    } else {
      await CameraApi.updateCamera(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    nvrId: '',
    code: undefined,
    captureType: '',
    channel: undefined,
    location: undefined,
    remark: undefined
  }
  formRef.value?.resetFields()
}
</script>
